package com.example.mathseduc

import android.content.Intent
import android.os.Bundle
import android.widget.*
import androidx.appcompat.app.AppCompatActivity
import com.example.mathseduc.controllers.ControllerChapter
import com.example.mathseduc.controllers.ControllerLobby
import com.example.mathseduc.models.Lobby
import org.json.JSONObject


class CreateLobbyActivity : AppCompatActivity() {

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_create_lobby)

        var spinnerChapter = findViewById<Spinner>(R.id.spinnerChapter)

        // Fetch chapters from API
        val chaptersFromApi = ControllerChapter.getChapters()

        // Populate Spinner with fetched chapters
        if (chaptersFromApi != null) {
            val chapterNames = chaptersFromApi.map { it.name }.toTypedArray()

            val adapter = ArrayAdapter(this, android.R.layout.simple_spinner_item, chapterNames)
            adapter.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item)
            spinnerChapter.adapter = adapter
        }

        val buttonCreateLobby = findViewById<Button>(R.id.buttonCreateLobby)
        buttonCreateLobby.setOnClickListener {
            val lobbyName = findViewById<EditText>(R.id.editTextLobbyName).text.toString()
            val password = findViewById<EditText>(R.id.editTextPassword).text.toString()
            val nbPlayers = findViewById<EditText>(R.id.editTextNbPlayers).text.toString().toInt()
            val difficulty = findViewById<Spinner>(R.id.spinnerDifficulty).selectedItemPosition + 1
            val selectedChapterPosition = findViewById<Spinner>(R.id.spinnerChapter).selectedItemPosition
            val chapterId = chaptersFromApi?.getOrNull(selectedChapterPosition)?.id?.toInt() ?: -1

            // Créer un objet Lobby avec les valeurs du formulaire
            val lobbyData = JSONObject().apply {
                put("name", lobbyName)
                put("password", password)
                put("nbplayers", nbPlayers)
                put("idplayercreator", 53)
                put("idchapter", chapterId)
                put("difficulty", difficulty)
            }

            // Appeler la fonction pour créer le lobby
            val lobbyCreatedSuccessfully = ControllerLobby.createLobby(lobbyData)

            // Vérifier si la création du lobby a réussi
            if (lobbyCreatedSuccessfully) {
                val intent = Intent(this, ServerDetailsActivity::class.java)
                startActivity(intent)
            } else {
                Toast.makeText(this, "Échec de la création du lobby. Veuillez réessayer.", Toast.LENGTH_SHORT).show()
            }
        }
    }
}